@@ -37,7 +37,7 @@ class RegionEstimator(object):
                 Initialised instance of subclass of RegionEstimator
 
         """
-        # Check sensors:
+        ### Check sensors:
 
         # (Not checking sensor_id as that forms the index)
         assert 'latitude' in list(sensors.columns), "There is no latitude column in sensors dataframe"
@@ -47,22 +47,29 @@ class RegionEstimator(object):
         assert pd.to_numeric(sensors['longitude'], errors='coerce').notnull().all(), \
             "longitude column contains non-numeric values."
 
-        # Check regions
+        ### Check regions
         # (Not checking region_id as that forms the index)
         assert 'geometry' in list(regions.columns), "There is no geometry column in regions dataframe"
 
-        # Check actuals
+        ### Check actuals
         assert 'timestamp' in list(actuals.columns), "There is no timestamp column in actuals dataframe"
-        assert 'sensor_id' in list(actuals.columns), "There is no sensor_id column in actuals dataframe - this must " + \
-                                                  "match a sensor_id in sensors and shows which sensor made the reading."
+        assert 'sensor_id' in list(actuals.columns), "There is no sensor_id column in actuals dataframe"
 
-        assert len(list(actuals.columns)) > 2, "There are no measurement value columns in the actuals dataframe."
-
-        '''for column in list(actuals.columns):
+        # Check measurement columns have numeric or null data.
+        for column in list(actuals.columns):
             if column not in ['timestamp', 'sensor_id']:
                 df_temp = actuals.loc[actuals[column].notnull()]
                 assert pd.to_numeric(df_temp[column], errors='coerce').notnull().all(), \
-                    "actuals['" + column + "'] column contains non-numeric values."'''
+                    "actuals['" + column + "'] column contains non-numeric values (null values accepted)."
+
+        # Check that each sensor ID is present in the sensors dataframe index.
+        #allowed_sensors = sensors.index
+        #print(allowed_sensors)
+        #assert  , "Each sensor ID must match a sensor_id in sensors."
+
+        assert len(list(actuals.columns)) > 2, "There are no measurement value columns in the actuals dataframe."
+
+
 
 
         try:
@@ -93,9 +100,8 @@ class RegionEstimator(object):
         self.__get_all_region_sensors()
 
 
-
     @abstractmethod
-    def get_estimate(self, timestamp, region_id):
+    def get_estimate(self, measurement, timestamp, region_id):
         raise NotImplementedError("Must override get_estimate")
 
 
@@ -138,7 +144,7 @@ class RegionEstimator(object):
             results = [self.get_region_estimation(measurement, region_id, timestamp, print_progress)]
         else:
             results = []
-            for index, region in self.regions.iterrows():
+            for index, _ in self.regions.iterrows():
                 if print_progress == True:
                     print('Calculating for region:', index)
                 results.append(self.get_region_estimation(measurement, index, timestamp, print_progress))
@@ -182,7 +188,7 @@ class RegionEstimator(object):
                                                'timestamp':timestamp})
         else:
             timestamps = sorted(self.actuals['timestamp'].unique())
-            for index, timestamp in enumerate(timestamps):
+            for _, timestamp in enumerate(timestamps):
                 if print_progress == True:
                     print(region_id, '    Calculating for timestamp:', timestamp)
 
@@ -224,10 +230,9 @@ class RegionEstimator(object):
         return len(self.actuals.loc[(self.actuals['timestamp'] == timestamp) & (self.actuals[measurement].notna())]) > 0
 
 
-
     def __get_all_region_neighbours(self):
         '''
-        Find all of the neighbours of each region and add to a 'neigbours' column in self.regions -
+        Find all of the neighbours of each region and add to a 'neighbours' column in self.regions -
         as comma-delimited string of region_ids
 
         :return: No return value
