@@ -9,12 +9,12 @@ from region_estimators.distance_simple_estimator import DistanceSimpleEstimator
 class RegionEstimatorFactory:
     factories = {}
 
-
+    @staticmethod
     def add_factory(id, region_estimator_factory):
-        RegionEstimatorFactory.factories.put[id] = region_estimator_factory
-    add_factory = staticmethod(add_factory)
+        RegionEstimatorFactory.factories[id] = region_estimator_factory
 
     # A Template Method:
+    @staticmethod
     def create(method_name, sensors, regions, actuals):
         class_name = get_classname(method_name)
         if class_name not in RegionEstimatorFactory.factories:
@@ -24,7 +24,6 @@ class RegionEstimatorFactory:
     region_estimator = staticmethod(create)
 
 
-
 def get_classname(method_name):
     if method_name == 'diffusion':
         return 'DiffusionEstimator'
@@ -32,6 +31,3 @@ def get_classname(method_name):
         return 'DistanceSimpleEstimator'
     else:
         raise ValueError('Method name does not exist')
-	
-
-
